@@ -1,4 +1,4 @@
 #!/usr/bin/env python
 # -*- coding:utf-8 -*-
 
-from .models import Message, DateUtil
+from .models import *
